@@ -13,7 +13,7 @@ class FeatureTransformer(PythonProxyBase):
     @keyword_only
     def __init__(
         self,
-        name: str = None,
+        name: Optional[str] = None,
         parameters: Optional[Dict[str, Any]] = None,
         progress_logger: Optional[ProgressLogger] = None,
         verify_count_remains_same: bool = False
